<?php

namespace Drupal\commerce_hubspot\EntitySync\Api;

use Drupal\commerce_hubspot\HubSpot\Helper as HubSpotHelper;
use Drupal\entity_sync\Client\ClientInterface as EntitySyncClientInterface;
use Drupal\hubspot_api\Manager as HubSpotManager;

/**
 * Entity Synchronization client adapter for the CRM Associations API.
 */
class AssociationClient implements EntitySyncClientInterface {

  /**
   * The HubSpot API manager.
   *
   * @var \Drupal\hubspot_api\Manager
   */
  protected $hubSpot;

  /**
   * The type of the origin object of the association.
   *
   * @var string
   */
  protected $fromObjectType;

  /**
   * The type of the target object of the association.
   *
   * @var string
   */
  protected $toObjectType;

  /**
   * The ID of the association type.
   *
   * @var string
   */
  protected $associationType;

  /**
   * Constructs a new AssociationClient object.
   *
   * @param \Drupal\hubspot_api\Manager $hubspot_manager
   *   The HubSpot API manager.
   * @param string $from_object_type
   *   The type of the origin object of the association.
   * @param string $to_object_type
   *   The type of the target object of the association.
   * @param int $association_type
   *   The ID of the association type.
   */
  public function __construct(
    HubSpotManager $hubspot_manager,
    string $from_object_type,
    string $to_object_type,
    int $association_type
  ) {
    $this->hubSpot = $hubspot_manager;
    $this->fromObjectType = $from_object_type;
    $this->toObjectType = $to_object_type;
    $this->associationType = $association_type;
  }

  /**
   * {@inheritdoc}
   */
  public function importList(array $filters = [], array $options = []) {
    throw new \Exception(
      'Importing a list of HubSpot CRM Associations is not supported.'
    );
  }

  /**
   * {@inheritdoc}
   */
  public function importEntity($id, array $options = []) {
    throw new \Exception(
      'Importing a HubSpot CRM Association is not supported yet.'
    );
  }

  /**
   * {@inheritdoc}
   */
  public function create(array $fields, array $options = []) {
    throw new \Exception(
      'CRM associations are currently considered updates as far the Entity Sync Client API is concerned because the entities involved in Drupal are mapped to their remote entities through different synchronizations and we do not need to track a remote ID that would be involved in a `create` action. That might change when we use separate entities for describing associations in Drupal, such as having User being group members of Organizations.'
    );
  }

  /**
   * {@inheritdoc}
   */
  public function update($id, array $fields, array $options = []) {
    $client_method = HubSpotHelper::objectTypeToClientMethod(
      $this->fromObjectType
    );

    return $this->hubSpot
      ->getHandler()
      ->crm()
      ->{$client_method}()
      ->associationsApi()
      ->create(
        $id,
        $this->toObjectType,
        $fields['referenced_entity_remote_id'],
        $this->associationType
      )
      ->jsonSerialize();
  }

}
