<?php

namespace Drupal\commerce_hubspot\EntitySync\Api;

use Drupal\entity_sync\Client\ProviderClientFactoryInterface;
use Drupal\hubspot_api\Manager as HubSpotManager;

/**
 * Factory for generating CRM Association API clients.
 */
class AssociationClientFactory implements ProviderClientFactoryInterface {

  /**
   * The HubSpot API manager.
   *
   * @var \Drupal\hubspot_api\Manager
   */
  protected $hubSpot;

  /**
   * Constructs a new AssociationClientFactory instance.
   *
   * @param \Drupal\hubspot_api\Manager $hubspot_manager
   *   The HubSpot API manager.
   */
  public function __construct(HubSpotManager $hubspot_manager) {
    $this->hubSpot = $hubspot_manager;
  }

  /**
   * {@inheritdoc}
   */
  public function get($sync_id, array $parameters) {
    $required = [
      'from_object_type',
      'to_object_type',
      'association_type',
    ];
    $missing_keys = array_diff($required, array_keys($parameters));
    if (count($missing_keys)) {
      throw new \InvalidArgumentException(sprintf(
        'Parameter(s) %s are required for creating the association client.',
        implode(', ', $missing_keys)
      ));
    }

    return new AssociationClient(
      $this->hubSpot,
      $parameters['from_object_type'],
      $parameters['to_object_type'],
      $parameters['association_type']
    );
  }

}
