<?php

namespace Drupal\commerce_hubspot\EntitySync\Api;

use Drupal\commerce_hubspot\HubSpot\Helper as HubSpotHelper;
use Drupal\entity_sync\Client\ClientInterface;
use Drupal\hubspot_api\Manager as HubSpotManager;

/**
 * The API client Entity Sync adapter for CRM object APIs.
 */
class ObjectClient implements ClientInterface {

  /**
   * The model factory for the API being called.
   *
   * @var \Drupal\commerce_hubspot\EntitySync\Api\ModelFactoryInterface
   */
  protected $modelFactory;

  /**
   * The HubSpot API manager.
   *
   * @var \Drupal\hubspot_api\Manager
   */
  protected $hubSpot;

  /**
   * The object type of the API that the client will be calling.
   *
   * @var string
   *
   * @see \HubSpot\Crm\ObjectType
   */
  protected $objectType;

  /**
   * Constructs a new ObjectClient object.
   *
   * @param \Drupal\hubspot_api\Manager $hubspot_manager
   *   The HubSpot API manager.
   * @param \Drupal\commerce_hubspot\EntitySync\Api\ModelFactoryInterface $model_factory
   *   The model factory for the API being called.
   * @param string $object_type
   *   The object type of the API that the client will be calling.
   */
  public function __construct(
    HubSpotManager $hubspot_manager,
    ModelFactoryInterface $model_factory,
    string $object_type
  ) {
    $this->hubSpot = $hubspot_manager;
    $this->modelFactory = $model_factory;
    $this->objectType = $object_type;
  }

  /**
   * {@inheritdoc}
   */
  public function importList(array $filters = [], array $options = []) {
    throw new \RuntimeException(
      'Importing a list of CRM objects from HubSpot is not supported yet.'
    );
  }

  /**
   * {@inheritdoc}
   */
  public function importEntity($id) {
    throw new \RuntimeException(
      'Importing individual CRM objects from HubSpot is not supported yet.'
    );
  }

  /**
   * {@inheritdoc}
   */
  public function create(array $fields, array $options = []) {
    $client_method = HubSpotHelper::objectTypeToClientMethod($this->objectType);

    $input = $this->modelFactory->simplePublicObjectInput();
    $input->setProperties($fields);

    return $this->hubSpot
      ->getHandler()
      ->crm()
      ->{$client_method}()
      ->basicApi()
      ->create($input)
      ->jsonSerialize();
  }

  /**
   * {@inheritdoc}
   */
  public function update($id, array $fields, array $options = []) {
    $client_method = HubSpotHelper::objectTypeToClientMethod($this->objectType);

    $input = $this->modelFactory->simplePublicObjectInput();
    $input->setProperties($fields);

    return $this->hubSpot
      ->getHandler()
      ->crm()
      ->{$client_method}()
      ->basicApi()
      ->update($id, $input)
      ->jsonSerialize();
  }

}
