<?php

namespace Drupal\commerce_hubspot\EntitySync\Api;

use Drupal\entity_sync\Client\ProviderClientFactoryInterface;
use Drupal\hubspot_api\Manager as HubSpotManager;
use HubSpot\Crm\ObjectType;

/**
 * Factory for generating CRM Object API clients.
 */
class ObjectClientFactory implements ProviderClientFactoryInterface {

  /**
   * The HubSpot API manager.
   *
   * @var \Drupal\hubspot_api\Manager
   */
  protected $hubSpot;

  /**
   * The class names of the factories for all supported APIs, keyed by API ID.
   *
   * @var array
   */
  protected $factoryMap = [
    ObjectType::COMPANIES => '\Drupal\commerce_hubspot\EntitySync\Api\CompanyModelFactory',
    ObjectType::CONTACTS => '\Drupal\commerce_hubspot\EntitySync\Api\ContactModelFactory',
    ObjectType::DEALS => '\Drupal\commerce_hubspot\EntitySync\Api\DealModelFactory',
    ObjectType::LINE_ITEMS => '\Drupal\commerce_hubspot\EntitySync\Api\LineItemModelFactory',
    ObjectType::PRODUCTS => '\Drupal\commerce_hubspot\EntitySync\Api\ProductModelFactory',
  ];

  /**
   * Constructs a new ObjectClientFactory object.
   *
   * @param \Drupal\hubspot_api\Manager $hubspot_manager
   *   The HubSpot API manager.
   */
  public function __construct(HubSpotManager $hubspot_manager) {
    $this->hubSpot = $hubspot_manager;
  }

  /**
   * {@inheritdoc}
   */
  public function get($sync_id, array $parameters) {
    if (!isset($parameters['object_type'])) {
      throw new \InvalidArgumentException(
        'Parameter object_type is required for creating the object client.'
      );
    }

    if (!array_key_exists($parameters['object_type'], $this->factoryMap)) {
      throw new \InvalidArgumentException(sprintf(
        'Unknown or unsupported object type "%s".',
        $parameters['object_type']
      ));
    }

    return new ObjectClient(
      $this->hubSpot,
      new $this->factoryMap[$parameters['object_type']](),
      $parameters['object_type']
    );
  }

}
