<?php

namespace Drupal\commerce_hubspot\HubSpot\Search;

/**
 * The interface for HubSpot finders.
 *
 * Finders facilitate making search queries to APIs that support them.
 */
interface FinderInterface {

  /**
   * Finds the HubSpot record uniquely identified by the given property.
   *
   * HubSpot allows registering properties as unique identifiers so that
   * duplicate records that have the same values for such properties cannot
   * be created. However, they may not be properly registered and we could
   * actually have duplicate records. The results of this search query may be
   * used with the assumption that there is one result only and in order to
   * alter records in subsequent queries. We do not want to just return the
   * first result since it could lead to altering the wrong record. We
   * therefore throw an exception if there is more than one result.
   *
   * @param string $name
   *   The name of the property.
   * @param string $value
   *   The value of the property.
   *
   * @return mixed|null
   *   The result object, or NULL if no HubSpot record was found.
   *
   * @throws \RuntimeException
   *   When more than one HubSpot record was found with the given property
   *   value.
   */
  public function findByUniqueIdentifier(string $name, string $value);

}
