<?php

namespace Drupal\commerce_hubspot\Plugin\EntitySync\FieldTransformer;

use Drupal\entity_sync\FieldTransformer\PluginBase;
use Drupal\Core\Entity\ContentEntityInterface;

/**
 * Transformer that exports the amount of a price field.
 *
 * Currently, it works with single-cardinality fields and on entities that have
 * a getter method that returns the price object. It makes it easy to export,
 * for example, the order, order item and product variation prices.
 *
 * HubSpot seems to have added support for multiple currencies. We may want to
 * look into how this works and support exporting the currency as well.
 *
 * @EntitySyncFieldTransformer(
 *   id = "commerce_hubspot_price"
 * )
 */
class Price extends PluginBase {

  /**
   * {@inheritdoc}
   */
  public function validateConfiguration() {
    parent::validateConfiguration();

    $this->validateConfigurationRequiredProperties([
      'getter',
    ]);
  }

  /**
   * {@inheritdoc}
   */
  protected function transformExportedValue(
    $value,
    ContentEntityInterface $local_entity,
    $remote_entity_id,
    array $field_info,
    array $context
  ) {
    return $value ? $value->getNumber() : NULL;
  }

}
