<?php

namespace Drupal\commerce_hubspot\Plugin\EntitySync\FieldTransformer;

use Drupal\entity_sync\FieldTransformer\PluginBase;
use Drupal\Core\Entity\ContentEntityInterface;

/**
 * Transformer that exports the remote ID of a referenced entity.
 *
 * @EntitySyncFieldTransformer(
 *   id = "commerce_hubspot_referenced_entity_remote_id"
 * )
 */
class ReferencedEntityRemoteId extends PluginBase {

  /**
   * {@inheritdoc}
   */
  public function validateConfiguration() {
    parent::validateConfiguration();

    $this->validateConfigurationRequiredProperties([
      'getter',
      'referenced_entity_remote_id_field',
    ]);
  }

  /**
   * {@inheritdoc}
   */
  protected function transformExportedValue(
    $value,
    ContentEntityInterface $local_entity,
    $remote_entity_id,
    array $field_info,
    array $context
  ) {
    if (!$value) {
      return NULL;
    }

    $field = $value->get(
      $this->configuration['referenced_entity_remote_id_field']
    );
    if ($field->isEmpty()) {
      return NULL;
    }

    return $field->getValue()[0]['value'];
  }

}
