<?php

namespace Drupal\commerce_hubspot\Plugin\EntitySync\FieldTransformer;

use Drupal\entity_sync\FieldTransformer\PluginBase;
use Drupal\Core\Entity\ContentEntityInterface;

/**
 * Transformer that exports timestamp fields.
 *
 * Timestamps in HubSpot are stored as microseconds, while in Drupal they are
 * stored in seconds. As of recent, CRM APIs seem to also support ISO8601
 * format even though microseconds still work. We could offer a configuration
 * option to choose in the future.
 *
 * @EntitySyncFieldTransformer(
 *   id = "commerce_hubspot_timestamp"
 * )
 */
class Timestamp extends PluginBase {

  /**
   * {@inheritdoc}
   */
  protected function transformExportedValue(
    $value,
    ContentEntityInterface $local_entity,
    $remote_entity_id,
    array $field_info,
    array $context
  ) {
    if ($value === NULL) {
      return NULL;
    }

    return $value * 1000;
  }

}
