<?php

namespace Drupal\commerce_hubspot\Plugin\EntitySync\OperationConfigurator;

/**
 * Plugin for HubSpot CRM Association export operations.
 *
 * Currently only exports are supported. Support for imports can also be added
 * in this plugin.
 *
 * phpcs:disable
 * @EntitySyncOperationConfigurator(
 *   id = "commerce_hubspot_association",
 *   label = @Translation("HubSpot CRM Association export"),
 *   description = @Translation(
 *     "Use 'HubSpot CRM Association export' types to export associations between entities."
 *   ),
 *   action_types = {
 *     "export_entity",
 *   },
 *   workflow_id = "entity_sync_operation_default",
 * )
 * phpcs:enable
 */
class Association extends Entity {

  /**
   * {@inheritdoc}
   */
  public function defaultConfiguration() {
    return [
      'action_type' => NULL,
      'local_entity' => [],
      'remote_resource' => [
        'provider_id' => 'hubspot',
        'id_field' => 'id',
        'client' => [
          'type' => 'factory',
          'service' => 'commerce_hubspot.entity_sync_client.association_factory',
          // These parameters should be defined in configuration.
          'parameters' => [
            'from_object_type' => NULL,
            'to_object_type' => NULL,
            'association_type' => NULL,
          ],
        ],
      ],
      'operations' => [],
      'field_mapping' => [],
      'ui' => [
        'disallowed_transitions' => [
          'fail',
          'complete',
        ],
        'uneditable_states' => [
          'cancelled',
          'running',
          'completed',
          'failed',
        ],
      ],
    ] + parent::defaultConfiguration();
  }

}
