<?php

namespace Drupal\commerce_hubspot\Plugin\EntitySync\OperationConfigurator;

use Drupal\commerce_hubspot\EntitySync\OperationConfigurator\PluginBase;
use Drupal\entity_sync\OperationConfigurator\FieldTrait\EntityTrait;

/**
 * Plugin for operations that relate to individual HubSpot objects.
 *
 * That is, for import/export operations between Drupal entities and HubSpot
 * objects. Currently only exports are supported. Support for imports should be
 * added in this plugin.
 *
 * We don't use `Object` as the name of this class because it is reserved by
 * PHP. We therefore use the equivalent in Drupal i.e. `Entity`.
 *
 * phpcs:disable
 * @EntitySyncOperationConfigurator(
 *   id = "commerce_hubspot_object",
 *   label = @Translation("HubSpot Object export"),
 *   description = @Translation(
 *     "Use 'HubSpot Object export' types to export Drupal Entities to HubSpot Objects."
 *   ),
 *   action_types = {
 *     "export_entity",
 *   },
 *   workflow_id = "entity_sync_operation_default",
 * )
 * phpcs:enable
 */
class Entity extends PluginBase {

  use EntityTrait;

  /**
   * The ID of the operation runner service.
   */
  const RUNNER_SERVICE_ID = 'commerce_hubspot.entity_sync_runner.entity';

  /**
   * {@inheritdoc}
   */
  public function defaultConfiguration() {
    return [
      'action_type' => NULL,
      'local_entity' => [],
      'remote_resource' => [
        'provider_id' => 'hubspot',
        'id_field' => 'id',
        'client' => [
          'type' => 'service',
        ],
      ],
      'operations' => [],
      'field_mapping' => [],
      'ui' => [
        'disallowed_transitions' => [
          'fail',
          'complete',
        ],
        'uneditable_states' => [
          'cancelled',
          'running',
          'completed',
          'failed',
        ],
      ],
    ] + parent::defaultConfiguration();
  }

  /**
   * {@inheritdoc}
   */
  public function bundleFieldDefinitions() {
    $fields = parent::bundleFieldDefinitions();

    // Add the dynamic entity reference field.
    $fields += $this->buildEntityBundleFieldDefinitions();

    return $fields;
  }

}
